{% if model_name == 'RandomForestClassifier' %}
default_hyperparameters = {'class_weight': None, 'criterion': 'gini', 'max_features': 'sqrt', 'min_samples_leaf': 1, 'n_estimators': 100, 'oob_score': False}
{% elif model_name == 'RandomForestRegressor' %}
default_hyperparameters = {'criterion': 'squared_error', 'max_features': 1.0, 'min_samples_leaf': 1, 'n_estimators': 100, 'oob_score': False}
{% elif model_name == 'ExtraTreesClassifier' %}
default_hyperparameters = {'class_weight': None, 'criterion': 'gini', 'max_features': 'sqrt', 'min_samples_leaf': 1, 'n_estimators': 100}
{% elif model_name == 'ExtraTreesRegressor' %}
default_hyperparameters = {'criterion': 'squared_error', 'max_features': 1.0, 'min_samples_leaf': 1, 'n_estimators': 100}
{% elif model_name == 'GradientBoostingClassifier' %}
default_hyperparameters = {'criterion': 'friedman_mse', 'loss': 'log_loss', 'max_features': None, 'min_samples_leaf': 1, 'n_estimators': 100, 'subsample': 1.0}
{% elif model_name == 'GradientBoostingRegressor' %}
default_hyperparameters = {'alpha': 0.9, 'criterion': 'friedman_mse', 'loss': 'squared_error', 'max_features': None, 'min_samples_leaf': 1, 'n_estimators': 100, 'subsample': 1.0}
{% elif model_name == 'AdaBoostClassifier' %}
default_hyperparameters = {'algorithm': 'SAMME.R', 'n_estimators': 50}
{% elif model_name == 'AdaBoostRegressor' %}
default_hyperparameters = {'loss': 'linear', 'n_estimators': 50}
{% elif model_name == 'DecisionTreeClassifier' %}
default_hyperparameters = {'criterion': 'gini', 'max_features': None, 'min_samples_leaf': 1}
{% elif model_name == 'DecisionTreeRegressor' %}
default_hyperparameters = {'criterion': 'squared_error', 'max_features': None, 'min_samples_leaf': 1}
{% elif model_name == 'SVC' %}
default_hyperparameters = {'C': 1.0, 'class_weight': None}
{% elif model_name == 'SVR' %}
default_hyperparameters = {'C': 1.0}
{% elif model_name == 'LinearSVC' %}
default_hyperparameters = {'C': 1.0, 'class_weight': None, 'intercept_scaling': 1, 'loss': 'squared_hinge', 'penalty': 'l2'}
{% elif model_name == 'LinearSVR' %}
default_hyperparameters = {'C': 1.0, 'intercept_scaling': 1.0, 'loss': 'epsilon_insensitive'}
{% elif model_name == 'LogisticRegression' %}
default_hyperparameters = {'C': 1.0, 'class_weight': None, 'penalty': 'l2', 'solver': 'lbfgs'}
{% elif model_name == 'SGDClassifier' %}
default_hyperparameters = {'alpha': 0.0001, 'class_weight': None, 'early_stopping': False, 'loss': 'hinge', 'penalty': 'l2'}
{% elif model_name == 'SGDRegressor' %}
default_hyperparameters = {'alpha': 0.0001, 'loss': 'squared_error', 'penalty': 'l2'}
{% elif model_name == 'Lasso' %}
default_hyperparameters = {'alpha': 1.0}
{% elif model_name == 'MLPClassifier' %}
default_hyperparameters = {'activation': 'relu', 'alpha': 0.0001, 'solver': 'adam'}
{% elif model_name == 'MLPRegressor' %}
default_hyperparameters = {'activation': 'relu', 'alpha': 0.0001, 'solver': 'adam'}
{% elif model_name == 'LGBMClassifier' or model_name == 'LGBMRegressor' %}
default_hyperparameters = {'class_weight': None, 'colsample_bytree': 1.0, 'min_child_samples': 20, 'min_child_weight': 0.001, 'n_estimators': 100, 'num_leaves': 31, 'reg_alpha': 0.1, 'reg_lambda': 0.1, 'subsample': 1.0, 'subsample_freq': 0}
{% elif model_name == 'XGBClassifier' %}
default_hyperparameters = {'colsample_bytree': 1, 'max_depth': 6, 'min_child_weight': 1, 'n_estimators': 100, 'reg_alpha': 0.1, 'reg_lambda': 0.1, 'subsample': 1}
{% elif model_name == 'XGBRegressor' %}
default_hyperparameters = {'colsample_bytree': 1, 'max_depth': 6, 'min_child_weight': 1, 'n_estimators': 100, 'reg_alpha': 0.1, 'reg_lambda': 0.1, 'subsample': 1}
{% elif model_name == 'CatBoostClassifier' or model_name == 'CatBoostRegressor' %}
default_hyperparameters = {'boosting_type': 'Plain', 'depth': 6, 'bootstrap_type': 'MVS'}
{% else %}
default_hyperparameters = {}
{% endif %}
study.enqueue_trial(default_hyperparameters)