# DISCARD IRRELEVANT COLUMNS
{% if pipeline.train_ignore_columns|length > 0 %}
__train_dataset.drop({{ pipeline.train_ignore_columns }}, axis=1, inplace=True, errors="ignore")
{% endif %}
{% if pipeline.test_ignore_columns|length > 0 %}
__test_dataset.drop({{ pipeline.test_ignore_columns }}, axis=1, inplace=True, errors="ignore")
{% endif %}